macro_rules! export_plugin {
($plugin_type:ty) => { ... };
}Expand description
Helper macro to export the plugin creation function with the correct ABI
macro_rules! export_plugin {
($plugin_type:ty) => { ... };
}Helper macro to export the plugin creation function with the correct ABI