macro_rules! export_plugin_with {
($plugin_type:ty, $constructor:expr) => { ... };
}Expand description
Helper macro to export the plugin creation function with a custom constructor
macro_rules! export_plugin_with {
($plugin_type:ty, $constructor:expr) => { ... };
}Helper macro to export the plugin creation function with a custom constructor