VanguardPlugin

Trait VanguardPlugin 

pub trait VanguardPlugin:
    Send
    + Sync
    + Debug {
    // Required methods
    fn metadata(&self) -> &PluginMetadata;
    fn validate<'life0, 'async_trait>(
        &'life0 self,
    ) -> Pin<Box<dyn Future<Output = ValidationResult> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn initialize<'life0, 'async_trait>(
        &'life0 self,
    ) -> Pin<Box<dyn Future<Output = Result<(), String>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn cleanup<'life0, 'async_trait>(
        &'life0 self,
    ) -> Pin<Box<dyn Future<Output = Result<(), String>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;

    // Provided methods
    fn is_compatible_with(&self, vanguard_version: &Version) -> bool { ... }
    fn config_schema(&self) -> Option<Value> { ... }
}
Trait that must be implemented by all Vanguard plugins

Required Methods

fn metadata(&self) -> &PluginMetadata

Get the plugin’s metadata

fn validate<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = ValidationResult> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Validate the plugin’s configuration and environment

fn initialize<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<(), String>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Initialize the plugin

fn cleanup<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<(), String>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Clean up plugin resources

Provided Methods

fn is_compatible_with(&self, vanguard_version: &Version) -> bool

Check if plugin is compatible with given Vanguard version

fn config_schema(&self) -> Option<Value>

Get plugin configuration schema

Implementors